@@ -347,13 +347,16 @@ bool wxStfApp::OnInit(void)
 
 int wxStfApp::OnExit()
 {
+#if wxUSE_CONFIG
+    GetDocManager()->FileHistorySave(*wxConfig::Get());
+#endif // wxUSE_CONFIG
+
+    delete GetDocManager();
+
 #ifdef WITH_PYTHON
     Exit_wxPython();
 #endif
 
-    GetDocManager()->FileHistorySave( *config );
-
-    delete wxDocManager::GetDocumentManager();
     return wxApp::OnExit();
 }
 
@@ -663,9 +666,9 @@ wxMenuBar *wxStfApp::CreateUnifiedMenuBar(wxStfDoc* doc) {
     m_edit_menu->AppendSeparator();
     m_edit_menu->AppendSubMenu(editSub,wxT("New window with..."));
     m_edit_menu->Append(
-                        ID_CONCATENATE,
-                        wxT("&Concatenate selected traces"),
-                        wxT("Create one large trace by merging selected traces in this file")
+                        ID_CONCATENATE_MULTICHANNEL,
+                        wxT("&Concatenate selected sweeps (multiple channels)"),
+                        wxT("Create one large sweep by merging selected sweeps in this file")
                         );
     wxMenu* m_view_menu = new wxMenu;
     m_view_menu->Append(
@@ -1374,7 +1377,7 @@ std::vector<stf::SectionPointer> wxStfApp::GetSectionsWithFits() const {
 wxString wxStfApp::GetVersionString() const {
     wxString verString;
     verString << wxT("Stimfit ")
-              << wxString(VERSION, wxConvLocal)
+              << wxString(PACKAGE_VERSION, wxConvLocal)
 #ifdef _STFDEBUG
               << wxT(", debug build, ");
 #else
